@@ -1,21 +1,23 @@
 import random
-from typing import Any, Union
+from typing import TYPE_CHECKING, Any, Union
 
 from pydantic import BaseModel
-from pydantic.fields import ModelField
 
 from pydantic_factories.factory import ModelFactory
 from pydantic_factories.utils import is_pydantic_model, is_union
 
 try:
     from ormar import Model
-except ImportError:  # pragma: no cover
+except ImportError:
     Model = BaseModel
 
+if TYPE_CHECKING:
+    from pydantic.fields import ModelField
+
 
 class OrmarModelFactory(ModelFactory[Model]):  # pragma: no cover
     @classmethod
-    def get_field_value(cls, model_field: ModelField, field_parameters: Union[dict, list, None] = None) -> Any:
+    def get_field_value(cls, model_field: "ModelField", field_parameters: Union[dict, list, None] = None) -> Any:
         """
         We need to handle here both choices and the fact that ormar sets values to be optional
         """
