@@ -63,7 +63,7 @@ def generate_constrained_number(
     """Generates a constrained number, output depends on the passed in callbacks"""
     if minimum is not None and maximum is not None:
         if multiple_of is None:
-            return cast(T, method(minimum, maximum))
+            return cast("T", method(minimum, maximum))
         if multiple_of >= minimum:
             return multiple_of
         result = minimum
@@ -72,4 +72,4 @@ def generate_constrained_number(
         return result
     if multiple_of is not None:
         return multiple_of
-    return cast(T, method())
+    return cast("T", method())
